searchData={"items":[{"type":"module","title":"ExRTCP.CompoundPacket","doc":"Functionalities for decoding and encoding compound RTCP packets.","ref":"ExRTCP.CompoundPacket.html"},{"type":"function","title":"ExRTCP.CompoundPacket.decode/1","doc":"Decodes compound RTCP packet.","ref":"ExRTCP.CompoundPacket.html#decode/1"},{"type":"function","title":"ExRTCP.CompoundPacket.encode/2","doc":"Encodes the packets as a compound packet and returns the resulting binary.\n\nOptions:\n\n  * `padding` - number of padding bytes added to the last packet,\nmust fulfill the same conditions as in `ExRTCP.Packet.encode/2`","ref":"ExRTCP.CompoundPacket.html#encode/2"},{"type":"module","title":"ExRTCP.Packet","doc":"RTCP packet encoding and decoding functionalities.","ref":"ExRTCP.Packet.html"},{"type":"module","title":"Examples - ExRTCP.Packet","doc":"```elixir\n  iex> packet = %ExRTCP.Packet.SenderReport{\n  ...>   ssrc: 123_456,\n  ...>   ntp_timestamp: 5_000_000,\n  ...>   rtp_timestamp: 436_133,\n  ...>   packet_count: 5,\n  ...>   octet_count: 89\n  ...> }\n  iex> encoded = ExRTCP.Packet.encode(packet, padding: 8)\n  iex> {:ok, ^packet} = ExRTCP.Packet.decode(encoded)\n  ```","ref":"ExRTCP.Packet.html#module-examples"},{"type":"function","title":"ExRTCP.Packet.decode/1","doc":"Decodes RTCP packet. Returns a struct representing the packet based on its type.","ref":"ExRTCP.Packet.html#decode/1"},{"type":"function","title":"ExRTCP.Packet.encode/2","doc":"Encodes the packet and returns the resulting binary.\n\nOptions:\n\n  * `padding` - number of padding bytes added to packet, no\npadding is added by default, must be multiple of 4, and smaller than 256","ref":"ExRTCP.Packet.html#encode/2"},{"type":"type","title":"ExRTCP.Packet.decode_error/0","doc":"Possible `decode/1` errors.\n\n  * `:invalid_packet` - this binary could not be parsed as a valid RTCP packet\n  * `:unknown_type` - this type of RTCP packet is not supported or does not exist","ref":"ExRTCP.Packet.html#t:decode_error/0"},{"type":"type","title":"ExRTCP.Packet.int16/0","doc":"","ref":"ExRTCP.Packet.html#t:int16/0"},{"type":"type","title":"ExRTCP.Packet.int24/0","doc":"","ref":"ExRTCP.Packet.html#t:int24/0"},{"type":"type","title":"ExRTCP.Packet.packet/0","doc":"","ref":"ExRTCP.Packet.html#t:packet/0"},{"type":"type","title":"ExRTCP.Packet.uint8/0","doc":"","ref":"ExRTCP.Packet.html#t:uint8/0"},{"type":"type","title":"ExRTCP.Packet.uint13/0","doc":"","ref":"ExRTCP.Packet.html#t:uint13/0"},{"type":"type","title":"ExRTCP.Packet.uint16/0","doc":"","ref":"ExRTCP.Packet.html#t:uint16/0"},{"type":"type","title":"ExRTCP.Packet.uint24/0","doc":"","ref":"ExRTCP.Packet.html#t:uint24/0"},{"type":"type","title":"ExRTCP.Packet.uint32/0","doc":"","ref":"ExRTCP.Packet.html#t:uint32/0"},{"type":"type","title":"ExRTCP.Packet.uint64/0","doc":"","ref":"ExRTCP.Packet.html#t:uint64/0"},{"type":"module","title":"ExRTCP.Packet.TransportFeedback.CC","doc":"Transport-wide Congestion Control Feedback packet type\n(`draft-holmer-rmcat-transport-wide-cc-extensions-01`).","ref":"ExRTCP.Packet.TransportFeedback.CC.html"},{"type":"type","title":"ExRTCP.Packet.TransportFeedback.CC.siema/0","doc":"","ref":"ExRTCP.Packet.TransportFeedback.CC.html#t:siema/0"},{"type":"type","title":"ExRTCP.Packet.TransportFeedback.CC.status_symbol/0","doc":"Status of reported packets.\n\nSee `draft-holmer-rmcat-transport-wide-cc-extensions-01`, sec. 3.1.1 for further explanation.\nNotice that this RFC section lists `11` value as *RESERVED*, but it is used in further\nexamples as *packet received, w/o timestamp*, thus we treat it as a valid value.","ref":"ExRTCP.Packet.TransportFeedback.CC.html#t:status_symbol/0"},{"type":"type","title":"ExRTCP.Packet.TransportFeedback.CC.t/0","doc":"Struct representing Transport-wide Congestion Control\nFeedback RTCP packet.\n\nPacket will be properly encoded only if the values are valid. Refer to\n`draft-holmer-rmcat-transport-wide-cc-extensions-01`, sec. 3 to see\nwhat values are considered valid, here's some important remarks:\n  * `packet_status_count` must match the actual number of packets described\n  by the feedback,\n  * length of `recv_deltas` must match the number of packets that\n  were described as `:small_delta` or `:large_delta` by the `packet_chunks`,\n  * each of `recv_deltas` values must fit in 2 bytes (if it's `:large_delta`)\n  or 1 byte (if it's `:small_delta`).\n\nTrying to encode a packet with invalid values will result in an undefined\nbehaviour (most likely `encode/1` will raise).","ref":"ExRTCP.Packet.TransportFeedback.CC.html#t:t/0"},{"type":"module","title":"ExRTCP.Packet.TransportFeedback.CC.RunLength","doc":"Run Length chunk contained by Transport-wide\nCongestion Control RTCP packets.","ref":"ExRTCP.Packet.TransportFeedback.CC.RunLength.html"},{"type":"type","title":"ExRTCP.Packet.TransportFeedback.CC.RunLength.t/0","doc":"Struct representing the Run Length chunk.\n\nSee `draft-holmer-rmcat-transport-wide-cc-extensions-01`,\nsec. 3.1.3 for further explanation.","ref":"ExRTCP.Packet.TransportFeedback.CC.RunLength.html#t:t/0"},{"type":"module","title":"ExRTCP.Packet.TransportFeedback.CC.StatusVector","doc":"Status Vector chunk contained by Transport-wide\nCongestion Control RTCP packets.","ref":"ExRTCP.Packet.TransportFeedback.CC.StatusVector.html"},{"type":"type","title":"ExRTCP.Packet.TransportFeedback.CC.StatusVector.t/0","doc":"Struct representing the Status Vector chunk.\n\n`symbols` list length must be equal to either `7` or `14`.\n\nSee `draft-holmer-rmcat-transport-wide-cc-extensions-01`,\nsec. 3.1.4 for further explanation.","ref":"ExRTCP.Packet.TransportFeedback.CC.StatusVector.html#t:t/0"},{"type":"module","title":"ExRTCP.Packet.TransportFeedback.NACK","doc":"Transport layer feedback message with generic NACKs\npacket type (`RFC 4585`, sec. 6.2.1).","ref":"ExRTCP.Packet.TransportFeedback.NACK.html"},{"type":"function","title":"ExRTCP.Packet.TransportFeedback.NACK.from_sequence_numbers/3","doc":"Creates `t:t/0` from a list of sequence numbers.\n\nWorks with assumption that all of the sequence numbers will fit in a single feedback.","ref":"ExRTCP.Packet.TransportFeedback.NACK.html#from_sequence_numbers/3"},{"type":"function","title":"ExRTCP.Packet.TransportFeedback.NACK.to_sequence_numbers/1","doc":"Creates a list of sequence numbers from `t:t/0`.","ref":"ExRTCP.Packet.TransportFeedback.NACK.html#to_sequence_numbers/1"},{"type":"type","title":"ExRTCP.Packet.TransportFeedback.NACK.generic_nack/0","doc":"Generic NACK message, as described in `RFC 4585`, sec. 6.2.1.\n`blp` must be a 16-bit binary.","ref":"ExRTCP.Packet.TransportFeedback.NACK.html#t:generic_nack/0"},{"type":"type","title":"ExRTCP.Packet.TransportFeedback.NACK.t/0","doc":"Struct representing Transport layer NACK feedback RTCP message.","ref":"ExRTCP.Packet.TransportFeedback.NACK.html#t:t/0"},{"type":"module","title":"ExRTCP.Packet.PayloadFeedback.FIR","doc":"Payload-specific Full Intra Request (FIR)\npacket type (`RFC 5104`, sec. 4.3.1).","ref":"ExRTCP.Packet.PayloadFeedback.FIR.html"},{"type":"type","title":"ExRTCP.Packet.PayloadFeedback.FIR.entry/0","doc":"","ref":"ExRTCP.Packet.PayloadFeedback.FIR.html#t:entry/0"},{"type":"type","title":"ExRTCP.Packet.PayloadFeedback.FIR.t/0","doc":"Struct representing Payload-specific FIR feedback RTCP message.","ref":"ExRTCP.Packet.PayloadFeedback.FIR.html#t:t/0"},{"type":"module","title":"ExRTCP.Packet.PayloadFeedback.PLI","doc":"Payload-specific Picture Loss Indication (PLI)\npacket type (`RFC 4585`, sec. 6.3.1).","ref":"ExRTCP.Packet.PayloadFeedback.PLI.html"},{"type":"type","title":"ExRTCP.Packet.PayloadFeedback.PLI.t/0","doc":"Struct representing Payload-specific PLI feedback RTCP message.","ref":"ExRTCP.Packet.PayloadFeedback.PLI.html#t:t/0"},{"type":"module","title":"ExRTCP.Packet.Goodbye","doc":"Goodbye RTCP packet type (`RFC 3550`).","ref":"ExRTCP.Packet.Goodbye.html"},{"type":"type","title":"ExRTCP.Packet.Goodbye.t/0","doc":"Struct representing Goodbye RTCP packet.","ref":"ExRTCP.Packet.Goodbye.html#t:t/0"},{"type":"module","title":"ExRTCP.Packet.ReceiverReport","doc":"Receiver Report RTCP packet type (`RFC 3550`).","ref":"ExRTCP.Packet.ReceiverReport.html"},{"type":"type","title":"ExRTCP.Packet.ReceiverReport.t/0","doc":"Struct representing Receiver Report RTCP packet.\n\nNumber of reception reports is always less than 32 for a single receiver report.","ref":"ExRTCP.Packet.ReceiverReport.html#t:t/0"},{"type":"module","title":"ExRTCP.Packet.ReceptionReport","doc":"Reception Reports carried by Sender/Receiver Report RTCP packets.","ref":"ExRTCP.Packet.ReceptionReport.html"},{"type":"type","title":"ExRTCP.Packet.ReceptionReport.t/0","doc":"Struct representing reception report present in Sender/Receiver Report RTCP packets.","ref":"ExRTCP.Packet.ReceptionReport.html#t:t/0"},{"type":"module","title":"ExRTCP.Packet.SenderReport","doc":"Sender Report RTCP packet type (`RFC 3550`).","ref":"ExRTCP.Packet.SenderReport.html"},{"type":"type","title":"ExRTCP.Packet.SenderReport.t/0","doc":"Struct representing Sender Report RTCP packet.\n\nNumber of reception reports is always less than 32 for a single sender report.","ref":"ExRTCP.Packet.SenderReport.html#t:t/0"},{"type":"module","title":"ExRTCP.Packet.SourceDescription","doc":"Source Description RTCP packet type (`RFC 3550`).","ref":"ExRTCP.Packet.SourceDescription.html"},{"type":"type","title":"ExRTCP.Packet.SourceDescription.t/0","doc":"Struct representing Source Description RTCP packet.\n\nNumber of chunks is always less than 32 for a single source description packet.","ref":"ExRTCP.Packet.SourceDescription.html#t:t/0"},{"type":"module","title":"ExRTCP.Packet.SourceDescription.Chunk","doc":"Chunk contained by Source Description RTCP packets.","ref":"ExRTCP.Packet.SourceDescription.Chunk.html"},{"type":"type","title":"ExRTCP.Packet.SourceDescription.Chunk.t/0","doc":"Struct representing chunk contained by Source Description RTCP packets.","ref":"ExRTCP.Packet.SourceDescription.Chunk.html#t:t/0"},{"type":"module","title":"ExRTCP.Packet.SourceDescription.Chunk.Item","doc":"Item contained by chunks in Source Description RTCP packets.\n\nIncludes items specified by `RFC 3550` as well as the MID SDES item\nspecified in `RFC 8843`.","ref":"ExRTCP.Packet.SourceDescription.Chunk.Item.html"},{"type":"type","title":"ExRTCP.Packet.SourceDescription.Chunk.Item.item_type/0","doc":"","ref":"ExRTCP.Packet.SourceDescription.Chunk.Item.html#t:item_type/0"},{"type":"type","title":"ExRTCP.Packet.SourceDescription.Chunk.Item.t/0","doc":"Struct representing item contained by chunks in Source Description RTCP packets.\n\nText must be shorter than 256 bytes.","ref":"ExRTCP.Packet.SourceDescription.Chunk.Item.html#t:t/0"},{"type":"extras","title":"ExRTCP","doc":"# ExRTCP\n\n[![Hex.pm](https://img.shields.io/hexpm/v/ex_rtcp.svg)](https://hex.pm/packages/ex_rtcp)\n[![API Docs](https://img.shields.io/badge/api-docs-yellow.svg?style=flat)](https://hexdocs.pm/ex_rtcp)\n[![CI](https://img.shields.io/github/actions/workflow/status/elixir-webrtc/ex_rtcp/ci.yml?logo=github&label=CI)](https://github.com/elixir-webrtc/ex_rtcp/actions/workflows/ci.yml)\n[![codecov](https://codecov.io/gh/elixir-webrtc/ex_rtcp/graph/badge.svg?token=0tlQeAdxhd)](https://codecov.io/gh/elixir-webrtc/ex_rtcp)\n\nImplementation of the RTCP protocol in Elixir. \n\nImplements packet types from:\n- [RFC 3550 - RTP: A Transport Protocol for Real-Time Applications](https://datatracker.ietf.org/doc/html/rfc3550)\n- [RFC 4585 - Extended RTP Profile for Real-time Transport Control Protocol (RTCP)-Based Feedback (RTP/AVPF)](https://datatracker.ietf.org/doc/html/rfc4585)\n- [RFC 5104 - Codec Control Messages in the RTP Audio-Visual Profile with Feedback (AVPF)](https://datatracker.ietf.org/doc/html/rfc5104)\n- [RTP Extensions for Transport-wide Congestion Control](https://datatracker.ietf.org/doc/html/draft-holmer-rmcat-transport-wide-cc-extensions-01)\n\nFor complete list of supported packet types, refer to the [documentation](https://hexdocs.pm/ex_rtcp/readme.html).\n\nSee [documentation page](https://hexdocs.pm/ex_rtcp/ExRTCP.Packet.html) of `ExRTCP.Packet` for usage examples.","ref":"readme.html"},{"type":"extras","title":"Installation - ExRTCP","doc":"Add `ex_rtcp` to dependencies in `mix.exs`:\n\n```elixir\ndef deps do\n  [\n    {:ex_rtcp, \"~> 0.3.0\"}\n  ]\nend\n```","ref":"readme.html#installation"}],"content_type":"text/markdown","producer":{"name":"ex_doc","version":[48,46,51,49,46,50]}}